To help you access, transform, analyze, and visualize 'ForestGEO' data, we developed a collection of R packages (https://forestgeo.github.io/fgeo/). This package, in particular, helps you to easily import, filter, and modify 'ForestGEO' data. To learn more about 'ForestGEO' visit https://forestgeo.si.edu/.
Maintainer: Mauro Lepore [email protected] (ORCID) [contractor]
Authors:
Richard Condit [email protected]
Suzanne Lao [email protected]
Anudeep Singh [email protected]
Other contributors:
CTFS-ForestGEO [email protected] [copyright holder, funder]
Useful links: